# AgentConnectorSpecificStats

Statistics periodically collected from a running AgentConnector. These statistics may be used to understand how the AgentConnector is performing, diagnose issues, and so on. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**system** | [**AgentConnectorSystemStats**](AgentConnectorSystemStats.md) |  | 
**transport** | [**AgentConnectorTransportStats**](AgentConnectorTransportStats.md) |  | 
**shares** | [**AgentConnectorShareStats**](AgentConnectorShareStats.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


